# Table of Contents

- [configuring-automated-nightly-runs-for-inbound-processors](<./configuring-automated-nightly-runs-for-inbound-processors.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Configuring Automated Nightly Runs for Inbound Processors](<./Configuring-Automated-Nightly-Runs-for-Inbound-Processors.md>)
  - [Overview](<./Configuring-Automated-Nightly-Runs-for-Inbound-Processors/Overview.md>)
  - [Prerequisites](<./Configuring-Automated-Nightly-Runs-for-Inbound-Processors/Prerequisites.md>)
  - [Procedure](<./Configuring-Automated-Nightly-Runs-for-Inbound-Processors/Procedure.md>)
